==> springfox-core-2.8.0-sources.jar: springfox/documentation/service/Documentation.java <==
/*
 *
 *  Copyright 2015 the original author or authors.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *
 */

package springfox.documentation.service;

import com.google.common.collect.Multimap;

import java.util.Collection;
import java.util.List;
import java.util.Set;

import static com.google.common.collect.Lists.*;

public class Documentation {
  private final String groupName;
  private final String basePath;
  private final Multimap<String, ApiListing> apiListings;
  private final Set<Tag> tags;
  private final ResourceListing resourceListing;
  private final Set<String> produces;
  private final Set<String> consumes;
  private final String host;
  private final Set<String> schemes;
  private final List<VendorExtension> vendorExtensions;

  public Documentation(
      String groupName,
      String basePath,
      Set<Tag> tags,
      Multimap<String, ApiListing> apiListings,
      ResourceListing resourceListing,
      Set<String> produces,
      Set<String> consumes,
      String host,
      Set<String> schemes,
      Collection<VendorExtension> vendorExtensions) {

    this.groupName = groupName;
    this.basePath = basePath;
    this.tags = tags;
    this.apiListings = apiListings;
    this.resourceListing = resourceListing;
    this.produces = produces;
    this.consumes = consumes;
    this.host = host;
    this.schemes = schemes;
    this.vendorExtensions = newArrayList(vendorExtensions);
  }

  public String getGroupName() {
    return groupName;
  }

  public Multimap<String, ApiListing> getApiListings() {
    return apiListings;
  }

  public ResourceListing getResourceListing() {
    return resourceListing;
  }

  public Set<Tag> getTags() {
    return tags;
  }

  public String getBasePath() {
    return basePath;
  }

  public List<String> getProduces() {
    return newArrayList(produces);
  }

  public String getHost() {
    return host;
  }

  public List<String> getSchemes() {
    return newArrayList(schemes);
  }

  public List<String> getConsumes() {
    return newArrayList(consumes);
  }

  public List<VendorExtension> getVendorExtensions() {
    return vendorExtensions;
  }
}

==> springfox-core-2.10.5-sources.jar: springfox/documentation/service/Documentation.java <==
/*
 *
 *  Copyright 2015-2019 the original author or authors.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *
 */

package springfox.documentation.service;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;


public class Documentation {
  private final String groupName;
  private final String basePath;
  private final Map<String, List<ApiListing>> apiListings;
  private final Set<Tag> tags;
  private final ResourceListing resourceListing;
  private final Set<String> produces;
  private final Set<String> consumes;
  private final String host;
  private final Set<String> schemes;
  private final List<Server> servers;
  private final DocumentationReference documentationReference;
  private final List<VendorExtension> vendorExtensions;

  @SuppressWarnings("ParameterNumber")
  public Documentation(
      String groupName,
      String basePath,
      Set<Tag> tags,
      Map<String, List<ApiListing>> apiListings,
      ResourceListing resourceListing,
      Set<String> produces,
      Set<String> consumes,
      String host,
      Set<String> schemes,
      List<Server> servers,
      DocumentationReference documentationReference,
      Collection<VendorExtension> vendorExtensions) {

    this.groupName = groupName;
    this.basePath = basePath;
    this.tags = tags;
    this.apiListings = apiListings;
    this.resourceListing = resourceListing;
    this.produces = produces;
    this.consumes = consumes;
    this.host = host;
    this.schemes = schemes;
    this.servers = servers;
    this.documentationReference = documentationReference;
    this.vendorExtensions = new ArrayList<>(vendorExtensions);
  }

  public String getGroupName() {
    return groupName;
  }

  public Map<String, List<ApiListing>> getApiListings() {
    return apiListings;
  }

  public ResourceListing getResourceListing() {
    return resourceListing;
  }

  public Set<Tag> getTags() {
    return tags;
  }

  public String getBasePath() {
    return basePath;
  }

  public List<String> getProduces() {
    return new ArrayList<>(produces);
  }

  public String getHost() {
    return host;
  }

  public List<String> getSchemes() {
    return new ArrayList<>(schemes);
  }

  public List<String> getConsumes() {
    return new ArrayList<>(consumes);
  }

  public List<VendorExtension> getVendorExtensions() {
    return vendorExtensions;
  }

  public List<Server> getServers() {
    return servers;
  }

  public DocumentationReference getDocumentationReference() {
    return documentationReference;
  }
}
